function DemonstrationMorphology()
%*************************************************************************
%*                                                                       *
%*  Demonstration file of mathematical morphology on an image. At first  *
%*  there is necessary to set up parameters of a camera in your computer *
%*  in section "camera setting" below.                                   *
%*                                                                       *
%*  Author: Karel Horak, Brno University of Technology, 2012             *
%*                                                                       *
%*************************************************************************

%% cleaning
clear all;
close all;
clc;

%% camera settings
imaqreset;
pause(2);
%kam = videoinput('winvideo',1,'RGB24_640x480');
kam = videoinput('winvideo',1,'YUY2_320x240');

%% parameters
Mode = 1; % 1=binary edge detection, 2=grayscale edge detection, 3=
n = 0;  % image counter
params = getselectedsource(kam);
%params.PanMode = 'manual';
%params.TiltMode = 'manual';
%params.ZoomMode = 'manual';
triggerconfig(kam, 'manual');

%% GUI
ScreenSize = get(0,'ScreenSize');
figure('Position',[10 1 ScreenSize(3)-20 ScreenSize(4)-70],'Color',[0.2 0.2 0.2],'KeyPressFcn',@MyKeyPressed);
hold on;
TextColor = [1 1 0];
DrawColor = [0 1 0];
FontSize  = 16;

%% image processing main loop
start(kam);
SE = strel('disk',2);
global AppRunning;
AppRunning = 1;
tic;
while (AppRunning == 1)
    %% image counter
    n = n + 1;
    
    %% image acquisition
    imgRGB = ycbcr2rgb(getsnapshot(kam));
    
    %% binary or grayscale mode
    if (Mode == 1) % binary
        imgBG = im2bw(imgRGB);
    else           % grayscale
        imgBG = rgb2gray(imgRGB);
    end;
    
    %% mathematical morphology
    imgME  = imgBG - imerode(imgBG, SE);
    imgMET = imgME > max(max(imgME))/5;
    imgMET = bwareaopen(imgMET, 200);
    
    %% results
    imgRGBME(:,:,1) = imgRGB(:,:,1);% - 255*uint8(imgME);
    imgRGBME(:,:,2) = imgRGB(:,:,2) - 255*uint8(imgMET);
    imgRGBME(:,:,3) = imgRGB(:,:,3) - 255*uint8(imgMET);
    subplot(2,2,1), imshow(imgRGB), axis image, title(['Original, FPS: ',num2str(n/toc,'%.1f')],'Color',TextColor,'FontSize',FontSize);
    subplot(2,2,2), imshow(imgBG), axis image, title('Binary / Grayscale','Color',TextColor,'FontSize',FontSize);
    subplot(2,2,3), imshow(imgME,[]), axis image, title('Binary / Grayscale Edge','Color',TextColor,'FontSize',FontSize);
    subplot(2,2,4), imshow(imgRGBME), axis image, title('Original + Edge','Color',TextColor,'FontSize',FontSize);
    
    pause(0.01);
end;

stop(kam);
delete(kam);
close all;


function MyKeyPressed(src, event) %#ok<INUSL>
%% stisk klavesy
global AppRunning;
switch event.Key
    case 'escape'
        AppRunning = 0;
end;
